@@ -4,10 +4,13 @@
 #include <stdint.h>
 #include <unistd.h>
 #include <hildon/hildon.h>
+#include <string.h>
 #include "plugin_lib.h"
 
 #include "main.h"
+#include "../libpcsxcore/misc.h"
 #include "../libpcsxcore/psemu_plugin_defs.h"
+#include "../libpcsxcore/cdrom.h"
 #include "common/readpng.h"
 #include "maemo_common.h"
 #include <libosso.h>
@@ -82,6 +85,54 @@ void show_notification(char* text)
 	}
 }
 
+#include <hildon/hildon-file-chooser-dialog.h>
+void change_disc()
+{
+	GtkWidget *dialog;
+
+	dialog = hildon_file_chooser_dialog_new (GTK_WINDOW(window), GTK_FILE_CHOOSER_ACTION_OPEN);
+
+	char currentFile[MAXPATHLEN];
+	strcpy(currentFile, GetIsoFile());
+	if (strlen(currentFile))
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER(dialog), currentFile);
+	else
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog), "/home/user/MyDocs/");
+
+	GtkFileFilter *filter=gtk_file_filter_new();
+	gtk_file_filter_add_pattern (filter,"*.bin");
+	gtk_file_filter_add_pattern (filter,"*.iso");
+	gtk_file_filter_add_pattern (filter,"*.img");
+	gtk_file_filter_add_pattern (filter,"*.z");
+	gtk_file_filter_add_pattern (filter,"*.znx");
+	gtk_file_filter_add_pattern (filter,"*.pbp");
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog),filter);
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+		char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		//if (strcmp(filename, currentFile)) {
+			CdromId[0] = '\0';
+			CdromLabel[0] = '\0';
+
+			set_cd_image(filename);
+			if (ReloadCdromPlugin() < 0)
+				printf("failed to load cdr plugin\n");
+			
+			if (CDR_open() < 0)
+				printf("failed to open cdr plugin\n");		
+
+			strcpy(file_name, strrchr(filename,'/'));
+
+			SetCdOpenCaseTime(time(NULL) + 3);
+			LidInterrupt();
+		//}
+		g_free (filename);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
 inline void key_press_event(int key2,int type)
 {
 	int  psxkey1 = -1, psxkey2 = -1;
@@ -123,7 +174,7 @@ inline void key_press_event(int key2,int type)
                     writepng(buf, image->mem, pl_buf_w,pl_buf_h);
 				}
 				char message[50];
-				sprintf(message,"Saved savestate slot: %i",state_slot);
+				sprintf(message,"Saved savestate slot: %i",state_slot + 1);
 				show_notification(message);
 			}
 			return;
@@ -135,8 +186,7 @@ inline void key_press_event(int key2,int type)
 			if (type == 1){
 				state_slot=(state_slot<9)?state_slot+1:0;
 				char message[50];
-				sprintf(message,"Savestate slot: %i",state_slot);
-				printf("%s\n", message);
+				sprintf(message,"Savestate slot: %i",state_slot + 1);
 				show_notification(message);
 			}
 			return;
@@ -144,11 +194,14 @@ inline void key_press_event(int key2,int type)
 			if (type == 1){
 				state_slot=(state_slot>0)?state_slot-1:9;
 				char message[50];
-				sprintf (message,"Savestate slot: %i",state_slot);
-				printf("%s\n", message);
+				sprintf (message,"Savestate slot: %i",state_slot + 1);
 				show_notification(message);
 			}
 			return;
+		case 23:
+			if (type == 1)
+				change_disc();
+			return;
 	}
 
 	if (type == 1) {
@@ -183,7 +236,7 @@ void maemo_init(int *argc, char ***argv)
 	for (i=0;i<65536;i++)
 		keymap[i]=164;
 	if (NULL != pFile) {
-		for(i=0;i<23;i++){
+		for(i=0;i<24;i++){
 			fscanf(pFile, "%i",&ch);
 			keymap[ch]=i;
 		}
@@ -286,7 +339,7 @@ void *hildon_flip(void)
 
 	}
 
-	if (g_maemo_opts&8)
+	if (g_maemo_opts & 8)
 		maemo_x11_update_keys();
 	else
 		/* process GTK+ events */
