@@ -464,7 +464,7 @@ long CALLBACK GPUopen(int hwndGPU)
 	 //bDrawDither=FALSE;
 	// bUseLines=FALSE;
 	 bUseFrameLimit=FALSE;
-	 bUseFrameSkip=FALSE;
+	 //bUseFrameSkip=FALSE;
 	 iFrameLimit=0;
 	 fFrameRate=50.0f;
 	 iOffscreenDrawing=0;
@@ -484,7 +484,7 @@ long CALLBACK GPUopen(int hwndGPU)
      //bKeepRatio = TRUE;
 	 iScanBlend=0;
 	 //iVRamSize=0;
-	 iTexGarbageCollection=0;
+	 //iTexGarbageCollection=0;
 	 iBlurBuffer=0;
 	 //iHiResTextures=0;
 	 iNoScreenSaver=0;
@@ -2669,6 +2669,9 @@ void CALLBACK GPUrearmedCallbacks(const void **cbs)
     bUseFastMdec = cbs_->gpu_peopsgl.bUseFastMdec;
     iTexGarbageCollection = cbs_->gpu_peopsgl.iTexGarbageCollection;
     iVRamSize = cbs_->gpu_peopsgl.iVRamSize;
+
+	//bUseFrameSkip = cbs_->frameskip ? TRUE : FALSE; 
+	bUseFrameSkip = FALSE; 
 }
 
 static void flipEGL(void)
